package com.gs.statistics;


import com.gs.utils.DBService;
import com.gs.utils.ScfSitebasic;
import com.jfinal.aop.Inject;
import com.jfinal.config.*;
import com.jfinal.core.Const;
import com.jfinal.ext.handler.ContextPathHandler;
import com.jfinal.plugin.activerecord.ActiveRecordPlugin;
import com.jfinal.plugin.activerecord.CaseInsensitiveContainerFactory;
import com.jfinal.plugin.activerecord.dialect.MysqlDialect;
import com.jfinal.plugin.cron4j.Cron4jPlugin;
import com.jfinal.plugin.druid.DruidPlugin;
import com.jfinal.plugin.ehcache.EhCachePlugin;
import com.jfinal.server.undertow.UndertowServer;
import com.jfinal.template.Engine;

public class Config extends JFinalConfig {
    @Inject
    DBService dbService;
    /**
     * 注意：用于启动的 main 方法可以在任意 java 类中创建，在此仅为方便演示
     *      才将 main 方法放在了 DemoConfig 中
     *
     *      开发项目时，建议新建一个 App.java 或者 Start.java 这样的专用
     *      启动入口类放置用于启动的 main 方法
     */
    public static void main(String[] args) {
        UndertowServer.start(Config.class, 8888, true);
    }

    public void configConstant(Constants me) {
        //在调用getPropertyToBoolean之前需要先调用loadPropertyFile
        loadPropertyFile("config.properties");
        //设置jfinal的开发模式
        // me.setDevMode(getPropertyToBoolean("devMode",true));
//
        String url=getProperty("upfile");
        me.setBaseUploadPath(url);// 配置文件上传路径
        me.setDevMode(true);
        me.setMaxPostSize(500* Const.DEFAULT_MAX_POST_SIZE);
        //开启支持注解，支持 Controller、Interceptor 之中使用 @Inject 注入业务层，并且自动实现 AOP
        me.setInjectDependency(true);
        me.setInjectSuperClass(true);
        me.setError404View("/error.html");
        me.setError500View("/error.html");
        //   me.setJsonFactory(new FastJsonFactory());

    }

    public void configRoute(Routes me) {
        me.setBaseViewPath("/webapp");
        //me.add(new RouteConfig());
        me.add("/api", StatisticsController.class);

    }

    public void configEngine(Engine me) {
        // me.setBaseTemplatePath("webapp");
        // me.setToClassPathSourceFactory();
    }
    public void configPlugin(Plugins me) {
        loadPropertyFile("config.properties");
        //  me.add(new JwtTokenPlugin(UserService.me));
        /**配置权限拦截插件*/
        int initialSize = getPropertyToInt("initialSize");
        int minIdle = getPropertyToInt("minIdle");
        int maxActive = getPropertyToInt("maxActive");
        //获取jdbc连接池
        String url=getProperty("jdbcUrl");
        String user=getProperty("user");
        String pw=getProperty("password");
        String driver=getProperty("jdbcDriver");
        me.add(new EhCachePlugin());
        DruidPlugin druidPlugin = new DruidPlugin(url, user,pw.trim());
        druidPlugin.setDriverClass(driver);
        druidPlugin.setValidationQuery("select 1 from scf_line");  //Users是你的数据库中的某一个表
        me.add(druidPlugin);

        ActiveRecordPlugin arp = new ActiveRecordPlugin(druidPlugin);
        //ActiveRecordPlugin arp = new ActiveRecordPlugin(druidPlugin);
        // arp. setContainerFactory(new CaseInsensitiveContainerFactory(true));
        // arp.getEngine().setToClassPathSourceFactory();
        arp.setShowSql(true);
        // 配置Sqlserver方言
        arp.setDialect(new MysqlDialect());
        arp.setShowSql(true);
        arp.addSqlTemplate("/sql/sql.sql");
        // 配置属性名(字段名)大小写不敏感容器工厂
        arp.setContainerFactory(new CaseInsensitiveContainerFactory());
        //_MappingKit.mapping(arp);
        arp.addMapping("Scf_SiteBasic", "Scf_SiteBasicID", ScfSitebasic.class);
        me.add(arp);
        Cron4jPlugin cp = new Cron4jPlugin();
//        cp.addTask(" 00 05 * * *  ", new TaskJob());
//        cp.addTask(" 0-59/1 * * * *", new TisJob());
        me.add(cp);

    }
    public void configInterceptor(Interceptors me)
    {
        //me.add(new JwtTokenInterceptor());
        // me.add(new JwtInterceptor()); // 权限拦截器
    }
    public void configHandler(Handlers me) {
        me.add(new ContextPathHandler("basePath"));
    }
    public void onStart() {
        System.out.println("系统启动完成后回调");
        System.out.println("初始化应用池");
        DBService.initDB();
        System.out.println("初始化应用池完成");



    }

}